####MBomb

MBomb(Gmail To Gmail) Mail Bombing! Send Unlimited Bombing on Inbox.

Sign in to your Gmail Visit https://www.google.com/settings/security/lesssecureapps Please, Turn on Less Secure App Logins from your Gamil Account.
MBomb means Mail-Bomb and it's works for Sending Unlimited Mail. You can send unlimited message Gmail to Gmail.

More information about the attack you can find [here].

### Installation

#### PyPi

For installation through the PyPI:

```sh
$ pip install mbomb==1.0.0
```
This method is prefered for installation of the most recent stable release.

#### For Termux
To use the mbomb type the following commands:

```sh
$pkg install python2 -y
$pkg install tqdm
$pkg install git -y
$git clone https://github.com/palahsu/MBomb.git
$cd MBomb.py
$python MBomb.py or python2 MBomb.py
```

#### For Debian-based GNU/Linux distributions:
To use the application, type in the following commands in GNU/Linux terminal.

```sh
$sudo install python2 -y
$sudo install tqdm
$sudo install git -y
$git clone https://github.com/palahsu/MBomb.git
$cd MBomb.py
$python MBomb.py or python2 MBomb.py
```

#### For Windows
To use the application, type in the following commands in Powershell or CMD:

```sh
$pip install python2 -y
$pip install tqdm
$pip install git -y
$git clone https://github.com/palahsu/MBomb.git
$cd MBomb.py
$python MBomb.py or python2 MBomb.py
```
###### stop execution: Ctrl + C

Legal disclaimer:
It only works through Gmail, it does not identify the user as a spammer in any way, it is only designed to send multiple messages at once.
Using Gmail SMTP. We are not responsible for any abuse or damage caused by this program. This tool for only educational purpose. Use at your own risk!

### Bugs, issues and contributing!

If you find [bugs] or have [suggestions] about improving the module, To work properly in Android you have to Turn On Data and Please, Turn on your less secure option from Gmail. Don't use for revenge!
Don't hesitate to contact me.

### License

This project is licensed under the MPL License - see the [LICENSE](https://github.com/palahsu/MBomb/blob/master/LICENSE) file for details.
Copyright (c) 2019-2020 palahsu

[here]: <https://en.wikipedia.org/wiki/mbom_(computer_security)>
[bugs]: <https://github.com/palahsu/MBomb/issues>
[suggestions]: <https://github.com/palahsu/MBomb/issues>